\name{berrmat}
\alias{berrmat}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Bayesian analysis of the errormatrix  }
\description{
  Uses Gibbs sampling to estimate the posterior of the error matrix
  based on the conjugate multinomial/Dirichlet model.
}
\usage{
berrmat(obs, Nprop, prior = NULL, Nprior = NULL, nsim = 5000, k = length(Nprop), noninf = 1/k, beta.noninf = 1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{obs}{A square matrix of observations }
  \item{Nprop}{The proportions of each class in the map.  Since the map
    is created, it is assumed that this will be known precisely. }
  \item{prior}{ A matrix of prior observations.  Should contain some of
    the classes in \code{obs}, and should be named the same way. If not
    supplied, then a non-informative matrix consisting of a \code{k} by
    \code{k} matrix with each cell \code{1/k}.
  }
  \item{Nprior}{ The proportions of the prior map in each class }
  \item{nsim}{ The number of simulations in the Gibbs sampler }
  \item{k}{ The assumed number of classes.  Shouldn't need this one. }
  \item{noninf}{ Sometimes the prior matrix will have zero observations
    in it, and we can add a small value \code{noninf} to it to make sure
    we can sample from a gamma distribution}
  \item{beta.noninf}{ The value for the non-informative prior for the
    beta distribution, used if the prior matrix is smaller than the
    observed matrix }
}
\details{
  Uses Gibbs sampling to sample from the posterior of the conjugate
  Bayesian model for a multinomial distribution.  Designed for the
  analysis of analysis of error matrices, the summary of a sampling
  scheme to assess the accuracy of a classification, typically a map.

  For the standard case, where we have an error matrix and we wish to
  use a non-informative prior, \code{berrmat} will simply draw
  \code{nsim} observations from a dirichlet distribution for each row of
  the error matrix, and then adjust the result according to
  \code{Nprop}.

  When we have real prior information and \code{Nprior} is different to
  \code{Nprop}, then we need to adjust the prior matrix to have the same
  marginals as the errormatrix.  We need to know the true proportions
  of the classes for both maps to do this.  We treat this as a latent
  class model, and at each draw of the Gibbs sampler, we estimate the
  true proportions (i.e. column proportions), adjust the prior matrix,
  then continue.
}
\value{
  Returns a \code{nsim} by \code{k*k} matrix, and gives it a class \code{berrmatrix}.
  
}

\author{ Robert Denham <Robert.Denham@nrm.qld.gov.au>}


\seealso{ \code{\link{total}} }
\examples{

#Imagine a land-use map from the Baffle catchment of
#Queensland, Australia
baffle <- matrix(c(5,0,2,0,1,41,1,0,0,1,4,0,0,0,0,5),4,4)
baffle.p <- c(0.05034146,0.84161955,0.07216152,0.03587746)
dimnames(baffle)[[1]] <- dimnames(baffle)[[2]] <-
   c("Class18","Class20",  "Class107", "Class151")

#And imagine we also had information from the neighbouring
#catchment Boyne
boyne <- matrix(c(3,1,0,0,1,29,0,0,0,0,10,1,0,0,0,9),4,4)
boyne.p <- c( 0.07232752 ,0.90277579 ,0.00543547 ,0.01946122)
dimnames(boyne)[[1]] <- dimnames(boyne)[[2]]<-
   c("Class18","Class20",  "Class107", "Class151")

#Using a non-informative prior 
baffle.noninf <- berrmat(baffle,baffle.p)
mean(baffle.noninf)

#but if we used boyne as the prior matrix:
baffle.inf <- berrmat(baffle,baffle.p, boyne,boyne.p)
mean(baffle.inf)

#and sometimes we only have partial information...
#we can still use this.
boyne2 <- boyne[1:2,1:2]
boyne2.p <- boyne.p[1:2]/sum(boyne.p[1:2])
baffle.pinf <- berrmat(baffle,baffle.p, boyne2,boyne2.p)
mean(boyne2.p)
}

\keyword{ htest }% at least one, from doc/KEYWORDS

